# Request

A single update to apply to a document.

**Type:** object

## Properties

- **replaceAllText** ([ReplaceAllTextRequest](replacealltextrequest.md)): Replaces all instances of the specified text.
- **insertText** ([InsertTextRequest](inserttextrequest.md)): Inserts text at the specified location.
- **updateTextStyle** ([UpdateTextStyleRequest](updatetextstylerequest.md)): Updates the text style at the specified range.
- **createParagraphBullets** ([CreateParagraphBulletsRequest](createparagraphbulletsrequest.md)): Creates bullets for paragraphs.
- **deleteParagraphBullets** ([DeleteParagraphBulletsRequest](deleteparagraphbulletsrequest.md)): Deletes bullets from paragraphs.
- **createNamedRange** ([CreateNamedRangeRequest](createnamedrangerequest.md)): Creates a named range.
- **deleteNamedRange** ([DeleteNamedRangeRequest](deletenamedrangerequest.md)): Deletes a named range.
- **updateParagraphStyle** ([UpdateParagraphStyleRequest](updateparagraphstylerequest.md)): Updates the paragraph style at the specified range.
- **deleteContentRange** ([DeleteContentRangeRequest](deletecontentrangerequest.md)): Deletes content from the document.
- **insertInlineImage** ([InsertInlineImageRequest](insertinlineimagerequest.md)): Inserts an inline image at the specified location.
- **insertTable** ([InsertTableRequest](inserttablerequest.md)): Inserts a table at the specified location.
- **insertTableRow** ([InsertTableRowRequest](inserttablerowrequest.md)): Inserts an empty row into a table.
- **insertTableColumn** ([InsertTableColumnRequest](inserttablecolumnrequest.md)): Inserts an empty column into a table.
- **deleteTableRow** ([DeleteTableRowRequest](deletetablerowrequest.md)): Deletes a row from a table.
- **deleteTableColumn** ([DeleteTableColumnRequest](deletetablecolumnrequest.md)): Deletes a column from a table.
- **insertPageBreak** ([InsertPageBreakRequest](insertpagebreakrequest.md)): Inserts a page break at the specified location.
- **deletePositionedObject** ([DeletePositionedObjectRequest](deletepositionedobjectrequest.md)): Deletes a positioned object from the document.
- **updateTableColumnProperties** ([UpdateTableColumnPropertiesRequest](updatetablecolumnpropertiesrequest.md)): Updates the properties of columns in a table.
- **updateTableCellStyle** ([UpdateTableCellStyleRequest](updatetablecellstylerequest.md)): Updates the style of table cells.
- **updateTableRowStyle** ([UpdateTableRowStyleRequest](updatetablerowstylerequest.md)): Updates the row style in a table.
- **replaceImage** ([ReplaceImageRequest](replaceimagerequest.md)): Replaces an image in the document.
- **updateDocumentStyle** ([UpdateDocumentStyleRequest](updatedocumentstylerequest.md)): Updates the style of the document.
- **mergeTableCells** ([MergeTableCellsRequest](mergetablecellsrequest.md)): Merges cells in a table.
- **unmergeTableCells** ([UnmergeTableCellsRequest](unmergetablecellsrequest.md)): Unmerges cells in a table.
- **createHeader** ([CreateHeaderRequest](createheaderrequest.md)): Creates a header.
- **createFooter** ([CreateFooterRequest](createfooterrequest.md)): Creates a footer.
- **createFootnote** ([CreateFootnoteRequest](createfootnoterequest.md)): Creates a footnote.
- **replaceNamedRangeContent** ([ReplaceNamedRangeContentRequest](replacenamedrangecontentrequest.md)): Replaces the content in a named range.
- **updateSectionStyle** ([UpdateSectionStyleRequest](updatesectionstylerequest.md)): Updates the section style of the specified range.
- **insertSectionBreak** ([InsertSectionBreakRequest](insertsectionbreakrequest.md)): Inserts a section break at the specified location.
- **deleteHeader** ([DeleteHeaderRequest](deleteheaderrequest.md)): Deletes a header from the document.
- **deleteFooter** ([DeleteFooterRequest](deletefooterrequest.md)): Deletes a footer from the document.
- **pinTableHeaderRows** ([PinTableHeaderRowsRequest](pintableheaderrowsrequest.md)): Updates the number of pinned header rows in a table.
- **addDocumentTab** ([AddDocumentTabRequest](adddocumenttabrequest.md)): Adds a document tab.
- **deleteTab** ([DeleteTabRequest](deletetabrequest.md)): Deletes a document tab.
- **updateDocumentTabProperties** ([UpdateDocumentTabPropertiesRequest](updatedocumenttabpropertiesrequest.md)): Updates the properties of a document tab.
- **insertPerson** ([InsertPersonRequest](insertpersonrequest.md)): Inserts a person mention.
- **insertDate** ([InsertDateRequest](insertdaterequest.md)): Inserts a date.
